<?php

namespace Codemanas\WooPreviewEmailsPro\Helpers;

final class DependencyManager {

	private static ?DependencyManager $_instance = null;
	private static array $active_plugins;

	public static function get_instance(): ?DependencyManager {
		return ( self::$_instance == null ) ? self::$_instance = new self() : self::$_instance;
	}

	private function __construct() {
		$this->load_active_plugins();
	}

	private function __clone() {
	}

	/**
	 * Loads the active plugins.
	 *
	 * This method retrieves the list of currently active plugins and stores them in the $active_plugins variable.
	 * If the site is running as a multisite, it also retrieves the list of active sitewide plugins and merges
	 * it with the list of active plugins.
	 *
	 * @return void
	 */
	private function load_active_plugins() {
		self::$active_plugins = (array) get_option( 'active_plugins', array() );

		if ( is_multisite() ) {
			self::$active_plugins = array_merge( self::$active_plugins, get_site_option( 'active_sitewide_plugins', array() ) );
		}
	}

	public function is_free_active() {
		return in_array( 'woo-preview-emails/woocommerce-preview-emails.php', self::$active_plugins ) || array_key_exists( 'woo-preview-emails/woocommerce-preview-emails.php', self::$active_plugins );

	}

	/**
	 * Checks if the WooCommerce plugin is active.
	 *
	 * This method checks if the WooCommerce plugin is active by searching for it in the list of active plugins.
	 *
	 * @return bool True if the WooCommerce plugin is active, false otherwise.
	 */
	public function is_woocommerce_active(): bool {
		return in_array( 'woocommerce/woocommerce.php', self::$active_plugins ) || array_key_exists( 'woocommerce/woocommerce.php', self::$active_plugins );
	}

	public function is_woocommerce_booking_active() {
		return in_array( 'woocommerce-bookings/woocommerce-bookings.php', self::$active_plugins ) || array_key_exists( 'woocommerce-bookings/woocommerce-bookings.php', self::$active_plugins );
	}

	public function is_woocommerce_subscriptions_active() {
		return in_array( 'woocommerce-subscriptions/woocommerce-subscriptions.php', self::$active_plugins ) || array_key_exists( 'woocommerce-subscriptions/woocommerce-subscriptions.php', self::$active_plugins );
	}

	public function is_woocommerce_membership_active() {
		return in_array( 'woocommerce-memberships/woocommerce-memberships.php', self::$active_plugins ) || array_key_exists( 'woocommerce-memberships/woocommerce-memberships.php', self::$active_plugins );
	}
}