<?php

namespace Codemanas\WooPreviewEmailsPro\WooCommerce;

use Codemanas\WooPreviewEmailsPro\Helpers\DependencyManager;
use WC_Booking_Data_Store;

class Bookings {
	private static ?Bookings $_instance = null;

	public static function get_instance(): ?Bookings {
		return ( self::$_instance == null ) ? self::$_instance = new self() : self::$_instance;
	}

	private function __construct() {
		$dependency_manager = DependencyManager::get_instance();
		//abort early if WC Bookings plugin is not active
		if ( ! $dependency_manager->is_woocommerce_booking_active() ) {
			return;
		}

		add_filter( 'woo_preview_emails_unset_booking_emails', [ $this, 'show_booking_emails' ] );
		add_filter( 'woo_preview_additional_orderID', [ $this, 'setup_additional_data' ], 10, 3 );
		add_action( 'woo_preview_additional_order_trigger', [ $this, 'trigger' ], 10, 2 );
	}

	public function show_booking_emails(): array {
		return [];
	}

	/**
	 * Make ready for booking form submission template display.
	 *
	 * @param $result
	 * @param $index
	 * @param $orderID
	 *
	 * @return array|bool
	 */
	function setup_additional_data( $result, $index, $orderID ) {
		if ( $this->check_email_type( $index ) ) {
			$booking_ids = WC_Booking_Data_Store::get_booking_ids_from_order_id( $orderID );
			if ( ! empty( $booking_ids ) ) {
				$result = array(
					$index,
					$booking_ids[0]
				);
			} else {
				$result = array( 'error' => sprintf( __( 'No Booking ID found with this Order ID. Choose which is a booking order ! <br><br>Go to orders page to check %s.', 'woo-preview-emails-pro' ), '<a target="_blank" href="' . admin_url( 'edit.php?post_type=shop_order' ) . '">Order ID</a>' ) );
			}
		} elseif ( $index === 'WC_Email_Booking_Notification' ) {
			$booking_ids = WC_Booking_Data_Store::get_booking_ids_from_order_id( $orderID );
			if ( ! empty( $booking_ids ) ) {
				$result = array(
					'WC_Booking_Emails_Notification',
					$booking_ids[0],
					'Booking Notification',
					'Booking notification emails are sent manually from WooCommerce > Bookings > Send Notification.'
				);
			}
		}

		return $result;
	}

	/**
	 * Hook action in @woo_preview_additional_orderID
	 *
	 * @param $current_email
	 * @param $data
	 */
	public function trigger( $current_email, $data ) {
		if ( isset( $data['error'] ) ) {
			$msg = $data['error'];
			$msg .= '<p><a href="' . admin_url( 'admin.php?page=codemanas-woocommerce-preview-emails' ) . '">Take me back to choosing emails</a></p>';
			wp_die( $msg );
		}

		$index = $data[0];

		if ( $this->check_email_type( $index ) ) {
			//the $data[1] is the booking id
			$current_email->trigger( $data[1] );
		} elseif ( 'WC_Booking_Emails_Except_Notification' == $index ) {
			$current_email->trigger( $data[1] );
		} elseif ( 'WC_Booking_Emails_Notification' == $index ) {
			$current_email->heading              = "Booking Notification";
			$current_email->notification_message = "Booking notification emails are sent manually from WooCommerce > Bookings > Send Notification.";
			$current_email->trigger( $data[1], $current_email->heading, $current_email->notification_message, false );
		}
	}

	private function check_email_type( $index ) {
		return $index === 'WC_Email_Booking_Reminder' ||
		       $index === 'WC_Email_Booking_Confirmed' ||
		       $index === 'WC_Email_Booking_Cancelled' ||
		       $index === 'WC_Email_Admin_Booking_Cancelled' ||
		       $index === 'WC_Email_New_Booking' ||
		       $index === 'WC_Email_Booking_Pending_Confirmation';
	}
}