<?php

namespace Codemanas\WooPreviewEmailsPro\WooCommerce;

use Codemanas\WooPreviewEmailsPro\Helpers\DependencyManager;

class Subscriptions {
	private static ?Subscriptions $_instance = null;

	public static function get_instance(): ?Subscriptions {
		return ( self::$_instance == null ) ? self::$_instance = new self() : self::$_instance;
	}

	private function __construct() {
		$dependency_manager = DependencyManager::get_instance();
		if ( ! $dependency_manager->is_woocommerce_subscriptions_active() ) {
			return;
		}
		add_filter( 'woo_preview_emails_unset_subscription_emails', [ $this, 'show_subscription_emails' ] );
		add_filter( 'woo_preview_additional_orderID', [ $this, 'setup_additional_data' ], 10, 3 );
		add_action( 'woo_preview_additional_order_trigger', [ $this, 'trigger' ], 10, 2 );

	}

	public function show_subscription_emails(): array {
		return [];
	}

	public function setup_additional_data( $result, $index, $order_id ) {
		if ( ! wcs_order_contains_subscription( $order_id ) ) {
			return $result;
		}

		if ( $this->check_email_type( $index ) ) {
			$subscriptions      = wcs_get_subscriptions_for_order( $order_id );
			$first_subscription = '';
			foreach ( $subscriptions as $subscription ) {
				$first_subscription = $subscription;
				break;
			}
			$result = [
				$index,
				$first_subscription
			];
		}
		if ( $index === 'WCS_Email_Expired_Subscription' || $index === 'WCS_Email_On_Hold_Subscription' ) {
			$subscription_valid = wcs_order_contains_subscription( $order_id );
			if ( ! $subscription_valid ) {
				$result = array( 'error' => sprintf( __( 'This is not a valid subscription order. Please select a valid subscription order ID. <br><br>Go to orders page to check %s.', 'woo-preview-emails-pro' ), '<a target="_blank" href="' . admin_url( 'edit.php?post_type=shop_order' ) . '">Order ID</a>' ) );
			}
		} elseif ( $index === 'WC_Stripe_Email_Failed_Renewal_Authentication' ) {
			/** @method wcs_order_contains_subscription() */
			$subscription_valid = wcs_order_contains_subscription( $order_id );
			if ( ! $subscription_valid ) {
				$result = array( 'error' => sprintf( __( 'This is not a valid subscription order. Please select a valid subscription order ID. <br><br>Go to orders page to check %s.', 'woo-preview-emails-pro' ), '<a target="_blank" href="' . admin_url( 'edit.php?post_type=shop_order' ) . '">Order ID</a>' ) );
			} else {
				$result = array(
					'WC_Stripe_Email_Failed_Renewal_Authentication',
					wc_get_order( $order_id )
				);
			}
		}

		return $result;
	}

	public function trigger( $current_email, $data ) {
		$index = $data[0];
		if ( $this->check_email_type( $index ) ) {
			$current_email->trigger( $data[1] );
		}
	}

	private function check_email_type( $index ): bool {
		return $index == 'WCS_Email_Cancelled_Subscription' || $index == 'WCS_Email_Expired_Subscription' || $index == 'WCS_Email_On_Hold_Subscription';
	}
}